@@ -14,13 +14,11 @@ class MultiplesExperimentos:
                  puntos_importantes=None,
                  objeto_a_promediar=1,
                  tamanio_intervalo_para_promedio=100,
-                 arreglo_regiones_preferidas="",
-                 genera_matriz_recurrencia=False):
+                 arreglo_regiones_preferidas=""):
         self.lista_archivos = lista_archivos
         self.lista_experimentos = []
         self.resultados_entropia = {}
         self.resultados_divergencia = {}
-        self.genera_matriz_recurrencia = genera_matriz_recurrencia
         self.arreglo_regiones_preferidas = arreglo_regiones_preferidas
 
         if dimension_caja is None:
@@ -47,24 +45,31 @@ class MultiplesExperimentos:
                 if valor.get() is True:
                     count =+ 1
                     print("conteo de experimentos: ", count)
-                    self.lista_experimentos.append(Experimento(str(nombre),
-                                                   dimension_caja=self.dimension_caja,
-                                                   cantidad_filas=self.cantidad_filas,
-                                                   cantidad_columnas=self.cantidad_columnas,
-                                                   procesar_tiempo_archivo_irregular=
-                                                               self.procesar_tiempo_archivo_irregular,
-                                                   puntos_importantes=self.puntos_importantes))
-
+                    nuevo_experimento = Experimento(str(nombre),
+                                                    dimension_caja=self.dimension_caja,
+                                                    cantidad_filas=self.cantidad_filas,
+                                                    cantidad_columnas=self.cantidad_columnas,
+                                                    procesar_tiempo_archivo_irregular=
+                                                    self.procesar_tiempo_archivo_irregular,
+                                                    puntos_importantes=self.puntos_importantes)
+                    nuevo_experimento.calcula_velocidades()
+                    nuevo_experimento.calcula_regiones_cuadriculadas()
+                    nuevo_experimento.calcula_matrices_solo_regiones_preferidas()
+                    self.lista_experimentos.append(nuevo_experimento)
         else:
             for archivo in self.lista_archivos:
-                self.lista_experimentos.append(Experimento(archivo,
-                                                           dimension_caja=self.dimension_caja,
-                                                           cantidad_filas=self.cantidad_filas,
-                                                           cantidad_columnas=self.cantidad_columnas,
-                                                           procesar_tiempo_archivo_irregular=
-                                                           self.procesar_tiempo_archivo_irregular,
-                                                           puntos_importantes=self.puntos_importantes,
-                                                           ))
+                nuevo_experimento = Experimento(archivo,
+                                                dimension_caja=self.dimension_caja,
+                                                cantidad_filas=self.cantidad_filas,
+                                                cantidad_columnas=self.cantidad_columnas,
+                                                procesar_tiempo_archivo_irregular=
+                                                self.procesar_tiempo_archivo_irregular,
+                                                puntos_importantes=self.puntos_importantes,
+                                                )
+                nuevo_experimento.calcula_velocidades()
+                nuevo_experimento.calcula_regiones_cuadriculadas()
+                nuevo_experimento.calcula_matrices_solo_regiones_preferidas(self.arreglo_regiones_preferidas)
+                self.lista_experimentos.append(nuevo_experimento)
         self.procesa_diccionario_entropias()
         self.procesa_diccionario_divergencias()
 
