@@ -4,9 +4,11 @@ import numpy as np
 
 class ProcesamientoRegresionLineal:
     def __init__(self,
+                 nombre_regresion=None,
                  arreglo_a_procesar=None,
                  brinco_temporal=None,
                  longitud_ventana_tiempo=None):
+        self.nombre_regresion = nombre_regresion
         self.arreglo_a_procesar = arreglo_a_procesar
         self.brinco_temporal = brinco_temporal
         self.longitud_ventana_tiempo = longitud_ventana_tiempo
@@ -47,15 +49,8 @@ class ProcesamientoRegresionLineal:
     def agrega_categoria_regresion_lineal(self,
                                           diccionario_regresiones_lineales,
                                           nombre_tipo_regresion_lineal):
-        print("Agrego categoria de regresion_lineal")
-        print("--------------------------------------------------------------")
-        print("Diccionario general:", diccionario_regresiones_lineales)
-        print("Nombre a asignar:", nombre_tipo_regresion_lineal)
         nuevo_diccionario = self.genera_diccionario_informacion_actual()
         diccionario_regresiones_lineales[nombre_tipo_regresion_lineal] = nuevo_diccionario
-        print("Nuevo diccionario: ", diccionario_regresiones_lineales)
-
-
 
 
 def generar_series_tiempo(lista_a_procesar, brinco_temporal, longitud_ventana_tiempo):
@@ -91,7 +86,7 @@ def genera_pendientes_de_rectas_regresion_lineal(valores_x_regresion_lineal,
     cantidad_listas = len(valores_y_regresion_lineal)
     for indice in range(0, cantidad_listas):
         valores_x = valores_x_regresion_lineal[indice]
-        valores_y = valores_x_regresion_lineal[indice]
+        valores_y = valores_y_regresion_lineal[indice]
         delta_y = valores_y[-1] - valores_y[0]
         delta_x = valores_x[-1] - valores_x[0]
         pendiente_actual = delta_y/delta_x
